Given a vector of p-values, each concerning a row in the matrix X0,
dag_test_Holm() first applies Holm's method to the p-values and then also rejects
hypotheses corresponding to points coordinate-wise greater or equal to any
point whose hypothesis has been rejected.
Usage
dag_test_Holm(X0, p, alpha)
Value
A boolean vector of the same length as p with each element being TRUE if the corresponding hypothesis is rejected and FALSE otherwise.
Arguments
X0
a numeric matrix giving points corresponding to hypotheses.
p
a numeric vector taking values in (0, 1] such that length(p) == nrow(X0).
alpha
a numeric value in (0, 1] specifying the Type I error rate.