powered by
Implements the DAG testing procedure given in Algorithm 1 by MRCS2023;textualISS.
dag_test_ISS(X0, p, alpha)
A boolean vector of the same length as p with each element being TRUE if the corresponding hypothesis is rejected and FALSE otherwise.
p
TRUE
FALSE
a numeric matrix giving points corresponding to hypotheses.
a numeric vector taking values in (0, 1] such that length(p) == nrow(X0).
length(p) == nrow(X0)
a numeric value in (0, 1] specifying the Type I error rate.
MRCS2023ISS
X0 <- rbind(c(0.5, 0.6), c(0.8, 0.9), c(0.9, 0.8)) p <- c(0.02, 0.025, 0.1) alpha <- 0.05 dag_test_ISS(X0, p, alpha)
Run the code above in your browser using DataLab